## cometblue-lite

This is a very basic library for communicating with a Comet Blue thermostat or other compatible thermostats, such as Xavax, Silvercrest, ...
It was written with home assistant in mind. 

The full cometblue module has more features, but uses another bluetooth library, which may not always be usable.

## what works

Feature | Get | Set
------- | ------- | ------
Mode | :heavy_check_mark: | :heavy_check_mark:
Childlock | :heavy_check_mark: | :heavy_minus_sign:
Device Status | :heavy_check_mark: | :heavy_minus_sign:
Current Temperature | :heavy_check_mark: | :heavy_minus_sign:
Offset Temperature | :heavy_check_mark: | :heavy_check_mark:
Target Temperature | :heavy_check_mark: | :heavy_check_mark:
Open Window Detection | :heavy_multiplication_x: | :heavy_multiplication_x:
Holiday | :heavy_multiplication_x: | :heavy_multiplication_x:
Battery Level | :heavy_check_mark: | :heavy_minus_sign:
Low Battery | :heavy_check_mark: | :heavy_minus_sign:
Window Open Indicator | :heavy_multiplication_x: | :heavy_minus_sign:
Model | :heavy_check_mark: | :heavy_minus_sign:
Manufacturer Name | :heavy_check_mark: | :heavy_minus_sign:
Firmware Rev. | :heavy_check_mark: | :heavy_minus_sign:
Software Rev. | :heavy_check_mark: | :heavy_minus_sign: 
